# Generated by roxygen2: do not edit by hand

export(alignMatrices)
export(computeMoments)
export(computeMu)
export(generateSampleIO)
export(multiRun)
export(normalize)
export(optimParams)
export(plotBox)
export(plotCoefs)
export(plotHist)
export(pvalue)
importFrom(graphics,barplot)
importFrom(graphics,boxplot)
importFrom(graphics,hist)
importFrom(graphics,matplot)
importFrom(graphics,par)
importFrom(jointDiag,ajd)
importFrom(methods,new)
importFrom(pracma,integral)
importFrom(stats,integrate)
importFrom(stats,pchisq)
importFrom(stats,pnorm)
importFrom(stats,rbinom)
importFrom(stats,rmultinom)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,var)
useDynLib(morpheus, .registration = TRUE)
