

This archive contains the distribution Morpheus,
version 0.45:

  the ultimate configuration engine

This software is copyright (c) 2012 by Yandex LLC.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.


