#' @include utils.R
#'
#' @useDynLib morpheus, .registration = TRUE
#'
#' @importFrom jointDiag ajd
#' @importFrom stats rbinom rmultinom rnorm pnorm runif integrate sd var pchisq
#' @importFrom graphics boxplot barplot hist par matplot
#' @importFrom methods new
#' @importFrom pracma integral
#'
NULL
