% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot.R
\name{plotCoefs}
\alias{plotCoefs}
\title{plotCoefs}
\usage{
plotCoefs(mr, params, ...)
}
\arguments{
\item{mr}{List of parameters matrices}

\item{params}{True value of the parameters matrix}

\item{...}{Additional graphical parameters}
}
\value{
No return value, called for side effects.
}
\description{
Draw a graph of (averaged) coefficients estimations with their standard,
deviations ordered by mean values.
Note that the drawing does not correspond to a function; it is just a
convenient way to visualize the estimated parameters.
}
\examples{
# mr[[i]] is a list of estimated parameters matrices (here random matrices).
# Should be mr <- multiRun(...) --> see bootstrap example in ?multiRun.
simmr_path <- system.file("extdata", "simulateMr.R", package = "morpheus")
source(simmr_path)
mr_theta <- simulateMr(c(3,2), 10)
mr <- mr_theta$mr ; theta <- mr_theta$theta
plotCoefs(mr[[1]], theta)

}
