% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot.R
\name{plotBox}
\alias{plotBox}
\title{plotBox}
\usage{
plotBox(mr, x, y, ...)
}
\arguments{
\item{mr}{Output of multiRun(), list of lists of functions results}

\item{x}{Row index of the element inside the aggregated parameter}

\item{y}{Column index of the element inside the aggregated parameter}

\item{...}{Additional graphical parameters (xlab, ylab, ...)}
}
\value{
No return value, called for side effects.
}
\description{
Draw compared boxplots of a single parameter (scalar)
}
\examples{
# mr[[i]] is a list of estimated parameters matrices (here random matrices).
# Should be mr <- multiRun(...) --> see bootstrap example in ?multiRun.
simmr_path <- system.file("extdata", "simulateMr.R", package = "morpheus")
source(simmr_path)
source(simmr_path)
mr <- simulateMr(c(2,2), 10)$mr
plotBox(mr, 2, 1) #second row, first column

}
