% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{pvalue}
\alias{pvalue}
\title{pvalue}
\usage{
pvalue(mr)
}
\arguments{
\item{mr}{A list of matrices as output by multiRun()}
}
\value{
The matrix of p-values (same size as mr[[1]])
}
\description{
Compute the p-values of the tests beta[i,j] == 0 vs != 0
}
\examples{
# Next line should be a real call to multiRun()
mr <- list( list(matrix(c(1,2,3,4),ncol=2),matrix(c(2,2,1,1),ncol=2)) )
p <- pvalue(mr[[1]])

}
